ClauseStyle

Enum ClauseStyle 

pub enum ClauseStyle {
    Fill,
    Expanded,
}

Variants



Fill

Each clause goes on its own line; within a clause, items pack until the line width and then wrap. The default: compact and deterministic.



Expanded

Each clause keyword goes on its own line and the clause body is indented below it, with one comma separated item per line. The classic SQL look.